You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hive.apache.org by sp...@apache.org on 2017/05/17 14:42:50 UTC

[2/4] hive git commit: Revert "HIVE-16088: Fix hive conf property name introduced in HIVE-12767 (Barna Zsombor Klara, reviewed by Sergio Pena)"

Revert "HIVE-16088: Fix hive conf property name introduced in HIVE-12767 (Barna Zsombor Klara, reviewed by Sergio Pena)"

This reverts commit 2dfcea5a95b7d623484b8be50755b817fbc91ce0.


Project: http://git-wip-us.apache.org/repos/asf/hive/repo
Commit: http://git-wip-us.apache.org/repos/asf/hive/commit/d69758cb
Tree: http://git-wip-us.apache.org/repos/asf/hive/tree/d69758cb
Diff: http://git-wip-us.apache.org/repos/asf/hive/diff/d69758cb

Branch: refs/heads/branch-2.3
Commit: d69758cb96eab2d6f0b22a952ef56154be5ed866
Parents: 0907b41
Author: Sergio Pena <se...@cloudera.com>
Authored: Wed May 17 09:30:55 2017 -0500
Committer: Sergio Pena <se...@cloudera.com>
Committed: Wed May 17 09:30:55 2017 -0500

----------------------------------------------------------------------
 common/src/java/org/apache/hadoop/hive/conf/HiveConf.java    | 2 +-
 ql/src/java/org/apache/hadoop/hive/ql/exec/DDLTask.java      | 4 ++--
 ql/src/test/queries/clientpositive/parquet_int96_timestamp.q | 4 ++--
 3 files changed, 5 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/hive/blob/d69758cb/common/src/java/org/apache/hadoop/hive/conf/HiveConf.java
----------------------------------------------------------------------
diff --git a/common/src/java/org/apache/hadoop/hive/conf/HiveConf.java b/common/src/java/org/apache/hadoop/hive/conf/HiveConf.java
index ebbb8d9..330bd3f 100644
--- a/common/src/java/org/apache/hadoop/hive/conf/HiveConf.java
+++ b/common/src/java/org/apache/hadoop/hive/conf/HiveConf.java
@@ -1333,7 +1333,7 @@ public class HiveConf extends Configuration {
     HIVE_PARQUET_TIMESTAMP_SKIP_CONVERSION("hive.parquet.timestamp.skip.conversion", true,
         "Current Hive implementation of parquet stores timestamps to UTC, this flag allows skipping of the conversion" +
             "on reading parquet files from other tools"),
-    HIVE_PARQUET_INT96_DEFAULT_UTC_WRITE_ZONE("hive.parquet.mr.int96.enable.utc.write.zone", false,
+    PARQUET_INT96_DEFAULT_UTC_WRITE_ZONE("parquet.mr.int96.enable.utc.write.zone", false,
         "Enable this variable to use UTC as the default timezone for new Parquet tables."),
     HIVE_INT_TIMESTAMP_CONVERSION_IN_SECONDS("hive.int.timestamp.conversion.in.seconds", false,
         "Boolean/tinyint/smallint/int/bigint value is interpreted as milliseconds during the timestamp conversion.\n" +

http://git-wip-us.apache.org/repos/asf/hive/blob/d69758cb/ql/src/java/org/apache/hadoop/hive/ql/exec/DDLTask.java
----------------------------------------------------------------------
diff --git a/ql/src/test/queries/clientpositive/parquet_int96_timestamp.q b/ql/src/test/queries/clientpositive/parquet_int96_timestamp.q
index 5de2c3f..e5eb610 100644
--- a/ql/src/test/queries/clientpositive/parquet_int96_timestamp.q
+++ b/ql/src/test/queries/clientpositive/parquet_int96_timestamp.q
@@ -1,7 +1,7 @@
 create table dummy (id int);
 insert into table dummy values (1);
 
-set hive.parquet.mr.int96.enable.utc.write.zone=true;
+set parquet.mr.int96.enable.utc.write.zone=true;
 set hive.parquet.timestamp.skip.conversion=false;
 
 -- read/write timestamps using UTC as default write zone
@@ -18,7 +18,7 @@ select * from timestamps;
 describe formatted timestamps;
 drop table timestamps;
 
-set hive.parquet.mr.int96.enable.utc.write.zone=false;
+set parquet.mr.int96.enable.utc.write.zone=false;
 
 -- read/write timestamps using local timezone
 create table timestamps (ts timestamp) stored as parquet;
diff --git a/ql/src/java/org/apache/hadoop/hive/ql/exec/DDLTask.java b/ql/src/java/org/apache/hadoop/hive/ql/exec/DDLTask.java
index 917e565..2b13477 100644
--- a/ql/src/java/org/apache/hadoop/hive/ql/exec/DDLTask.java
+++ b/ql/src/java/org/apache/hadoop/hive/ql/exec/DDLTask.java
@@ -4341,11 +4341,11 @@ public class DDLTask extends Task<DDLWork> implements Serializable {
       }
     }
 
     // If HIVE_PARQUET_INT96_DEFAULT_UTC_WRITE_ZONE is set to True, then set new Parquet tables timezone
     // to UTC by default (only if the table property is not set)
     if (tbl.getSerializationLib().equals(ParquetHiveSerDe.class.getName())) {
       SessionState ss = SessionState.get();
-      if (ss.getConf().getBoolVar(ConfVars.HIVE_PARQUET_INT96_DEFAULT_UTC_WRITE_ZONE)) {
+      if (ss.getConf().getBoolVar(ConfVars.PARQUET_INT96_DEFAULT_UTC_WRITE_ZONE)) {
         String parquetTimezone = tbl.getProperty(ParquetTableUtils.PARQUET_INT96_WRITE_ZONE_PROPERTY);
         if (parquetTimezone == null || parquetTimezone.isEmpty()) {
           tbl.setProperty(ParquetTableUtils.PARQUET_INT96_WRITE_ZONE_PROPERTY, ParquetTableUtils.PARQUET_INT96_NO_ADJUSTMENT_ZONE);

http://git-wip-us.apache.org/repos/asf/hive/blob/d69758cb/ql/src/test/queries/clientpositive/parquet_int96_timestamp.q
----------------------------------------------------------------------
@@ -4341,11 +4341,11 @@ public class DDLTask extends Task<DDLWork> implements Serializable {
     }
 
-    // If HIVE_PARQUET_INT96_DEFAULT_UTC_WRITE_ZONE is set to True, then set new Parquet tables timezone
+    // If PARQUET_INT96_DEFAULT_UTC_WRITE_ZONE is set to True, then set new Parquet tables timezone
     // to UTC by default (only if the table property is not set)
     if (tbl.getSerializationLib().equals(ParquetHiveSerDe.class.getName())) {